% Generates time series data for the S-system described in ToyNetwork.m
%
% Output:
% TS:     time series data (columns: t, X1, X2, X3, X4)
%
% Wolfgang Beyer, 2007

% Simulate the differential equations
% [0 5]         time interval
% [1.4 ... 0.4] initial values for X1, X2, X3, X4
% [12 ... .8]   parameter values of the S-System
testSoln=ode45(@ToyNetwork,[0 5],[1.4; 2.7; 1.2; 0.4],[],[12 -.8 8 .5 3 .75 2 .5 10 .5 3 .75 5 .5 .2 6 .8]);
new_t=linspace(0,5,51);
new_x=deval(testSoln,new_t);
TS=[new_t' new_x'];

% delete unused variables
clear new_t;
clear new_x;
clear testSoln;

% add Gaussian noise
TS(:,2)=TS(:,2)+normrnd(0,.04,51,1);
TS(:,3)=TS(:,3)+normrnd(0,.1,51,1);
TS(:,4)=TS(:,4)+normrnd(0,.11,51,1);
TS(:,5)=TS(:,5)+normrnd(0,.015,51,1);

% plot the generated data
plot(TS(:,1),[TS(:,2) TS(:,3) TS(:,4) TS(:,5)])
legend('X1','X2','X3','X4');

